@@ -428,35 +428,6 @@ class RMSE(Metric):
         result = torchmetrics.functional.mean_squared_error(y_score, y_true, squared=False)
         return result
 
-class R2(Metric):
-    """
-    R^2.
-    """
-
-    def __init__(self):
-        self._name = "r2"
-        self._maximize = False
-
-    def __call__(self, y_true, y_score):
-        """
-        Compute R^2 of predictions.
-        Parameters
-        ----------
-        y_true : np.ndarray
-            Target matrix or vector
-        y_score : np.ndarray
-            Score matrix or vector
-        Returns
-        -------
-        float
-            R^2 of predictions vs targets.
-        """
-        y_true = torch.tensor(y_true)
-        y_score = torch.tensor(y_score)
-        result = torchmetrics.functional.r2_score(y_score, y_true)
-        return result
-
-
 class AverageCosineSimilarity(Metric):
     def __init__(self):
         self._name = "avg_cosine_similarity"
