@@ -74,15 +74,31 @@ class AbstractNnTrainer(object):
         The base constructor
 
         Args:
-            neural_network (torch.nn.Module): The network intended to be trained.  If implementation is a gan, then this refers to the 'generator' network
-            optimizer_fn (Any, optional): factory method for the optimizer to be constructed and used for training during initialization. Defaults to torch.optim.Adam.
-            optimizer_params (Dict, optional): parameters for the optimizer function. Defaults to dict(lr=2e-2).
-            scheduler_fn (Any, optional): factory method for the optimizer scheduler to be constructed and used for training during initialization. Defaults to None.
-            scheduler_params (Dict, optional): parameters for the optimizer scheduler function. Defaults to field(default_factory=dict).
-            dtype (Any, optional): the type of data to allocate memory with during training. Defaults to torch.float32.
-            verbose (bool, optional): Will print as much output as possible if True. Defaults to False.
-            patience (int, optional): describes the stopping criteria number of epochs over which training losses are relatively the same. Defaults to 0.
-            logger (Logger, optional): logging utility to be used during runtime. must have an info method. Defaults to None.
+            neural_network (torch.nn.Module): 
+                The network intended to be trained.  If implementation is a gan, then this refers to the 'generator' network
+            optimizer_fn (Any, optional): 
+                The factory method for the optimizer to be constructed and used for training during initialization. Defaults to torch.optim.Adam.
+            optimizer_params (Dict, optional): 
+                Parameters for the optimizer function. Defaults to dict(lr=2e-2).
+            scheduler_fn (Any, optional): 
+                The factory method for the optimizer scheduler to be constructed and used for training during initialization. Defaults to None.
+            scheduler_params (Dict, optional): 
+                The parameters for the optimizer scheduler function. Defaults to field(default_factory=dict).
+            dtype (Any, optional): 
+                The type of data to allocate memory with during training. Defaults to torch.float32.
+            verbose (bool, optional): 
+                Will print as much output as possible if True. Defaults to False.
+            patience (int, optional): 
+                Describes the stopping criteria number of epochs over which training losses are relatively the same. Defaults to 0.
+            max_epoch_count (int, optional): 
+                The maximum number of epochs to train for.
+            batch_size (int, optional): 
+                The number of samples in each batch.
+            output_dir (str, optional): 
+                The directory to store data pertinent to these models.
+            logger (Logger, optional): 
+                The logger to use when outputting information
+
         """
         self._verbose = verbose
         self._patience = patience
@@ -200,11 +216,16 @@ class AbstractNnTrainer(object):
         The training method
         
         Args:
-            training_data_set (td.Dataset): The dataset intended to be used for training
-            validation_data_set (td.Dataset): The dataset intended to be used for validation. all metrics defined will be invokd on this set
-            callbacks (List[Callback], optional): The set of callbacks receiving event based data. Defaults to [].
-            loss_fn ([type], optional): The loss function to be used as the objective function during training. Defaults to torch.nn.MSELoss().
-            metrics (List[Metric], optional): List of metrics to be invoked on validation data. Defaults to [].
+            training_data_set (td.Dataset): 
+                The dataset intended to be used for training
+            validation_data_set (td.Dataset): 
+                The dataset intended to be used for validation. all metrics defined will be invokd on this set
+            callbacks (List[Callback], optional): 
+                The set of callbacks receiving event based data. Defaults to [].
+            loss_fn ([type], optional): 
+                The loss function to be used as the objective function during training. Defaults to torch.nn.MSELoss().
+            metrics (List[Metric], optional): 
+                List of metrics to be invoked on validation data. Defaults to [].
 
         Raises:
             NotImplementedError: [description]
