@@ -54,18 +54,21 @@ class WassersteinGanNnTrainer(AbstractNnTrainer):
         """Constructor
 
         Args:
-            generator_neural_network (torch.nn.Module): [description]
-            discriminator_neural_network (torch.nn.Module): [description]
-            generator_optimizer_fn (Any, optional): [description]. Defaults to torch.optim.Adam.
-            generator_optimizer_params (Dict, optional): [description]. Defaults to dict(lr=0.0002).
-            discriminator_optimizer_fn (Any, optional): [description]. Defaults to torch.optim.Adam.
-            discriminator_optimizer_params (Dict, optional): [description]. Defaults to dict(lr=0.0002).
-            scheduler_fn (Any, optional): [description]. Defaults to None.
-            scheduler_params (Dict, optional): [description]. Defaults to field(default_factory=dict).
-            dtype (Any, optional): [description]. Defaults to torch.float32.
-            verbose (bool, optional): [description]. Defaults to False.
-            patience (int, optional): [description]. Defaults to 0.
-            logger (Logger, optional): [description]. Defaults to None.
+            generator_neural_network (torch.nn.Module): The generator network
+            discriminator_neural_network (torch.nn.Module): The discriminator network
+            generator_optimizer_fn (Any, optional): Defaults to torch.optim.Adam.
+            generator_optimizer_params (Dict, optional): Defaults to dict(lr=0.0002).
+            discriminator_optimizer_fn (Any, optional): Defaults to torch.optim.Adam.
+            discriminator_optimizer_params (Dict, optional): Defaults to dict(lr=0.0002).
+            scheduler_fn (Any, optional): Defaults to None.
+            scheduler_params (Dict, optional): Defaults to field(default_factory=dict).
+            dtype (Any, optional): Defaults to torch.float32.
+            verbose (bool, optional): Defaults to False.
+            patience (int, optional): Defaults to 0.
+            max_epoch_count (int, optional): The maximum number of epochs to train for.
+            batch_size (int, optional): The number of samples in each batch.
+            output_dir (str, optional): The directory to store data pertinent to these models.
+            logger (Logger, optional): Defaults to None.
         """
         super().__init__(
             generator_neural_network, 
